# Tests requiring Internet connections are disabled by default
# pass --with internet to run them (e.g. when doing a local rebuild
# for sanity checks before committing)
%bcond_with internet


%global pypiname tox
Name:           python-tox
Version:        2.3.1
Release:        %mkrel 2
Summary:        Virtualenv-based automation of test activities
Group:          Development/Python

# file toxbootstrap.py is licensed under MIT License
License:        GPLv2+ and MIT
URL:            http://codespeak.net/tox
Source0:        http://pypi.python.org/packages/source/t/%{pypiname}/%{pypiname}-%{version}.tar.gz


BuildArch:      noarch
BuildRequires:  python2-devel
BuildRequires:  python-setuptools
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools

%description
Tox as is a generic virtualenv management and test command line tool you 
can use for:

 - checking your package installs correctly with different Python versions 
   and interpreters
 - running your tests in each of the environments, configuring your test tool 
   of choice
 - acting as a frontend to Continuous Integration servers, greatly reducing 
   boilerplate and merging CI and shell-based testing.

%package -n python2-%{pypiname}
Summary:        Virtualenv-based automation of test activities
Group:          Development/Python
Provides:       python-%{pypiname} = %{version}-%{release}
Requires:       python-py
Requires:       python-pluggy
# python3-virtualenv is rhbz#537246
Requires:       python-virtualenv
BuildRequires:  python-py
BuildRequires:  python-pytest
BuildRequires:  python-virtualenv

%description -n python2-%{pypiname}
Tox as is a generic virtualenv management and test command line tool you 
can use for:

 - checking your package installs correctly with different Python versions 
   and interpreters
 - running your tests in each of the environments, configuring your test tool 
   of choice
 - acting as a frontend to Continuous Integration servers, greatly reducing 
   boilerplate and merging CI and shell-based testing.


%package -n python3-%{pypiname}
Summary:        Virtualenv-based automation of test activities
Group:          Development/Python
Requires:       python3-py
Requires:       python3-pluggy
# python3-virtualenv is rhbz#537246
Requires:       python3-virtualenv
BuildRequires:  python3-py
BuildRequires:  python3-pytest
BuildRequires:  python3-virtualenv

%description -n python3-%{pypiname}
Tox as is a generic virtualenv management and test command line tool you 
can use for:

 - checking your package installs correctly with different Python versions 
   and interpreters
 - running your tests in each of the environments, configuring your test tool 
   of choice
 - acting as a frontend to Continuous Integration servers, greatly reducing 
   boilerplate and merging CI and shell-based testing.

%prep
%setup -q -n %{pypiname}-%{version}

# remove bundled egg-info
rm -rf %{pypiname}.egg-info

rm -rf %{py3dir}
cp -a . %{py3dir}


%build
%py2_build

pushd %{py3dir}
%py3_build
popd


%install
%py2_install
mv %{buildroot}%{_bindir}/tox %{buildroot}%{_bindir}/python2-tox
mv %{buildroot}%{_bindir}/tox-quickstart %{buildroot}%{_bindir}/python2-tox-quickstart

pushd %{py3dir}
%py3_install
popd

# if internet connection available, run tests
%if %{with internet}
%check
# python 2.7: fedora 17, fedora 18
# python 3.2: fedora 17
# python 3.3: fedora 18

%{__python2} setup.py test
%{__python3} setup.py test

%endif

%files -n python2-tox
%doc ISSUES.txt doc
%license LICENSE
%{_bindir}/python2-%{pypiname}
%{_bindir}/python2-%{pypiname}-quickstart
%{python2_sitelib}/%{pypiname}
%{python2_sitelib}/%{pypiname}-%{version}-py2.?.egg-info

%files -n python3-tox
%{_bindir}/%{pypiname}
%{_bindir}/%{pypiname}-quickstart
%{python3_sitelib}/%{pypiname}
%{python3_sitelib}/%{pypiname}-%{version}-py%{python3_version}.egg-info



%changelog
* Sun May 15 2016 ngompa <ngompa> 2.3.1-2.mga6
+ Revision: 1015696
- imported package python-tox

